#!/bin/bash

module load netcdf/4.4.1.1
module load python

SCRHOME=/gpfs/scratch/bsc32/bsc32786/
PROJ=pisces1d/ORCA2_OFF_PISCES/

OBS=obs/
OBSFILE=bbp700_pisces_climatology_lab1d.nc
MODEL=%EXPID%/EXP00/
MODELFILE=PISCES1D_1d_19600101_19691231_ptrc_T.nc

function getbias {

bias="$(python - $1 $2 << END
from netCDF4 import Dataset
import numpy as np
import os

#os.chdir('/esarchive/obs/argo/bgc/climatologies/')
obs=Dataset('$1')
bbp700obs = np.array(obs.variables['bbp700_all_mean'])
bbp700obs = np.reshape(bbp700obs, (np.shape(bbp700obs)[0], np.shape(bbp700obs)[1]))
bbp700obs[bbp700obs == 0.0] = np.nan
obs.close()

#os.chdir('/gpfs/scratch/bsc32/bsc32786/a1yt/EXP00')
mod = Dataset('$2')
bbp700mod = 2500.*(np.array(mod.variables['POC'])[-60:, :, 1, 1]+np.array(mod.variables['PHY'])[-60:, :, 1, 1])
for i in range(12):
    bbp700mod[i] = np.mean(bbp700mod[i::12],0)
bbp700mod = bbp700mod[:12]
bbp700mod[bbp700mod == 200000039192547557376] = np.nan
mod.close()

bbp700obs=np.log(bbp700obs)
bbp700mod=np.log(bbp700mod)

std=np.nanstd(bbp700obs)
mn=np.nanmean(bbp700obs)

bbp700obs=(bbp700obs-mn)/std
bbp700mod=(bbp700mod-mn)/std

bias = np.nanmean(bbp700obs - bbp700mod)

print(bias)

END
)"
}

getbias $SCRHOME$PROJ$OBS$OBSFILE $SCRHOME${MODEL}default/$MODELFILE

bias=(${bias})

echo $bias

cd $SCRHOME${MODEL}default/

mkdir -p ${OBS}
cd ${OBS}
touch refbias.txt
echo $bias >> refbias.txt

function makeparameters {

bias="$(python - $1 << END

import numpy as np
import random
from pandas import DataFrame

A=np.zeros((int($1),3))

for i in range(np.shape(A)[0]):
    A[i,0]=random.random()*0.035+0.015
    A[i,1]=random.random()*2.+1.
    A[i,2]=random.random()*3000.+1500.

A=DataFrame(A)

A.to_csv('00.csv')

END
)"
}

cd $SCRHOME$MODEL
rm -rf fc*
mkdir -p parameters
cd parameters
if find . -mindepth 1 -print -quit 2>/dev/null | grep -q .; then
    rm *
fi

makeparameters %NUMMEMBERS%

