#!/bin/bash

# Generates the 3x3 input files that will be used in the Pisces 1D configuration.
# Also copies the files for the default configuration

## EDIT HERE TO CHANGE THE LOCATION OF THE 1DPISCES
## DEFAULT: LAT=56, LON=-49 (LABRADOR SEA)
LAT=56.4
LON=-49.5

##
SCRHOME=/gpfs/scratch/bsc32/bsc32786/
PROJ=pisces1d/ORCA2_OFF_PISCES/
INPUTS=input/
XIOS=xios-2.5/
NEMO=release-4.0/

# MAKE EXPID DIRECTORY AND COPY ALL THE CONTENT FROM EXP00 (.XML, EXECUTABLES, AND NAMELISTS)
mkdir -p $SCRHOME/%EXPID%/
cd $SCRHOME/%EXPID%/
mkdir -p EXP00/default
cd EXP00/default
cp -R ${SCRHOME}${PROJ}${NEMO}cfgs/PISCES1D/EXP00/nemo .
cp -R ${SCRHOME}${PROJ}${NEMO}cfgs/PISCES1D/EXP00/namelist* .
cp -R ${SCRHOME}${PROJ}${NEMO}cfgs/PISCES1D/EXP00/*.xml .
cd $SCRHOME${PROJ}${INPUTS}

module load python
module load intel/2017.4
module load impi/2017.4
module load netcdf/4.4.1.1
module load hdf5/1.8.19

module load udunits/2.2.25
module load gsl/2.4

module load nco

function getindices {

inds="$(python - $1 $2 << END

import numpy as np
from geopy import distance
import sys
from netCDF4 import Dataset
import os

def mindistcoords(lat, lon, latitudes, longitudes):
    mindist = 20000
    minI = 0
    minJ = 0
    (x, y) = np.shape(latitudes)
    for I in range(len(latitudes[0])):
        for J in range(len(latitudes[:, 0])):
            if abs(lat - latitudes[J][I]) < 2 and abs(lon - longitudes[J][I]) < 2:
                dist = distance.distance((lat, lon), (latitudes[J][I], longitudes[J][I]))
                if dist < mindist:
                    mindist = dist
                    minI = I
                    minJ = J
    return minJ, minI

grid = Dataset('dyna_grid_T.nc', 'r', format='NETCDF4_CLASSIC')
lons = np.array(grid.variables['nav_lon'])
lats = np.array(grid.variables['nav_lat'])

ilt,iln=mindistcoords(float(sys.argv[1]),float(sys.argv[2]),lats,lons)

print(ilt)
print(iln)

END
)"
}

getindices $LAT $LON

inds=(${inds})
latmin=${inds[0]}-1

mkdir -p ${SCRHOME}${PROJ}${INPUTS}cropped


if find "${SCRHOME}${PROJ}${INPUTS}cropped" -mindepth 1 -print -quit 2>/dev/null | grep -q .; then
    rm ${SCRHOME}${PROJ}${INPUTS}cropped/*
fi

for file in *.nc
do
echo cropping $file
ncks -d x,$((inds[0]-1)),$((inds[0]+1)) -d y,$((inds[1]-1)),$((inds[1]+1)) ${file} cropped/${file}
done

cd $SCRHOME/%EXPID%/EXP00/default
cp -R ${SCRHOME}${PROJ}${INPUTS}cropped/* .